/******************************************************************************
 * 
 * Copyright 2012 - 2013 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/


package com.vektorsoft.demux.desktop.view;

import com.vektorsoft.demux.core.mva.DMXView;
import java.util.Collections;
import java.util.Map;
import java.util.Set;
import javafx.scene.Node;
import javafx.scene.layout.Pane;
import javafx.stage.Stage;

/**
 * <p>
 * This class represents root view of JavaFX application. All views added to
 * application are rooted in this view.
 * </p>
 * <p>
 * This view does not have any data associated, but merely serves as a container
 * for other views. When multiple subviews are added to this views,they will be
 * stacked on top of each other, with the last view being on top.
 * </p>
 */
public class JFXRootView implements DMXView {
    
    /** View ID of the root view. */
    public static final String JFX_ROOT_VIEW_ID = "com.vektorsoft.demux.desktop.jfxRootView";

    /**
     * Root node of JavaFX scene graph.
     */
    private Pane root;

    /**
     * Create new instance.
     *
     * @param stage JavaFX stage
     */
    public JFXRootView(Stage stage) {
        root = (Pane) stage.getScene().getRoot();
    }

    @Override
    public void render() {
        // do nothing
    }

    @Override
    public String getViewId() {
        return JFX_ROOT_VIEW_ID;
    }

    @Override
    public String getParentViewId() {
        return null;
    }

    @Override
    public Object viewPlacementConstraint() {
        return null;
    }

    @Override
    public void addChildView(DMXView child) {
        if (!(child.getViewUI() instanceof Node)) {
            throw new IllegalArgumentException("View must be instance of javafx.scene.Node");
        }
        root.getChildren().add((Node) child.getViewUI());
    }

    @Override
    public Set<String> getViewDataIds() {
        return Collections.EMPTY_SET;
    }

    @Override
    public void updateFromModel(Map<String, Object> dataMap) {
    }

    @Override
    public Object getViewUI() {
        return root;
    }
}